<!--
 Copyright European Organization for Nuclear Research (CERN)

 Licensed under the Apache License, Version 2.0 (the "License");
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://www.apache.org/licenses/LICENSE-2.0

 Authors:
 - Thomas Beermann, <thomas.beermann@cern.ch>, 2014
-->

$var title: Accounting
$var script: <script src="/static/accounting.js"></script>

<div class="h2">RSE Usage</div>

<div>RSE: <select name="rseselect" id="rseselect"></select> Interval: <select name="intvalselect" id="intvalselect"></select><button id="update">Update</button></div>
<div id="usageplot" style="height: 100% ; width: 90% ; margin: 0 auto; float:left"></div>
<div id="problem"></div>
