
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.19.0.post2',
    'branch_nick': '(HEAD',
    'revision_id': 'abbb6eaebb2bb7d90a19ec75dd6c44df31420818',
    'revno': 7733
}
